OnigCaptureIndex class

A captured range within a match. Mirrors IOnigCaptureIndex.

Constructors

OnigCaptureIndex(int start, int end, int length)
Creates a capture index spanning start to end, with length equal to end - start, all in UTF-16 code units.
const

Properties

end int
The offset, in UTF-16 code units, where the captured range ends.
final
hashCode int
The hash code for this object.
no setterinherited
length int
The length of the captured range, in UTF-16 code units.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
The offset, in UTF-16 code units, where the captured range starts.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited