OnigMatch class

The result of OnigScanner.findNextMatch. Mirrors IOnigMatch.

Constructors

OnigMatch(int index, List<OnigCaptureIndex> captureIndices)
Creates a match for pattern index with the given captureIndices.
const

Properties

captureIndices List<OnigCaptureIndex>
The capture ranges for this match, one per group, with the whole match's range as group 0.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Index of the pattern (within the scanner) that matched.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited