displayName property
A human-readable name for the language, e.g. for use as a label in a language picker.
Implementation
final String displayName;
A human-readable name for the language, e.g. for use as a label in a language picker.
final String displayName;