embedded property
The flattened grammars this language embeds, already expanded by
flattenBundledLanguage (in place of CodeLanguage's lazy thunk,
which can't cross an isolate boundary).
Implementation
final List<LangDescriptor> embedded;
The flattened grammars this language embeds, already expanded by
flattenBundledLanguage (in place of CodeLanguage's lazy thunk,
which can't cross an isolate boundary).
final List<LangDescriptor> embedded;